elfdump(1)

elfdump - Dumps selected parts of a 32-bit or a 64-bit ELF object file/archive and displays them in ELF style

As shipped in IRIX 6.5.5. Last changed in IRIX 6.5.5.

NAME
     elfdump - Dumps selected parts of a 32-bit or a 64-bit ELF object
     file/archive and displays them in ELF style

SYNOPSIS
     elfdump [-a] [-A] [-B] [-brief] [-c] [-C] [-cmt] [-cnt] [-cr]
     [-d<lowsection>,<highsection>] [-Dc] [-Dg] [-dinfo] [-dinst] [-Dl]
     [-dsym] [-Dsymlib [-Dt] [-e] [-f] [-F] [-g] [-G] [-h] [-hash] [-i]
     [-ifc] [-info] [-l] [-L] [-long] [-n sectionname] [-no_verbose] [-o]
     [-op] [-p] [-Paddrs] [-Pbinmap] [-Pfuncnode] [-Pgraph] [-Pperf]
     [-Pweak] [-r] [-R] [-reg] [-rpt] [-s] [-svr4] [-t]
     [-T<lowindex>,<highindex>] [-v] [-V] [-xl] [-xld] file

IMPLEMENTATION
     IRIX systems

DESCRIPTION
     The elfdump command dumps selected parts of a given ELF object file or
     an archive file.

     This command is supported on 32-bit or 64-bit ELF object files or ELF
     archives only.  Unless otherwise noted in the option description,
     options are supported on the O32, N32, and 64-bit ABIs.  In the case
     of an archive, options other than -g generate output from each object
     in the archive.  When the requested data does not exist in an object,
     and the -p option is not specified, only a header will be printed.

     elfdump accepts one or more of these options:

     -a   Dumps the archive header of each member of an archive.

     -A   Prints the beginning address of a section.  For some section
          content dumps it prints the virtual address for each line of
          section output.

     -B   Prints filename each detail line of output when -c is specified.

     -brief
          Dumps most sections in the file like -h, but leaves out sections
          whose names begin with .debug_, .rel, or .MIPS.

     -c   Dumps the string table.

     -C   Dumps decoded C++ symbol names.

     -cmt Dumps the .comment section.

     -cnt Dumps the .content sections.

     -cr  (O32 ABI only) Dumps compact relocation information.

     -d<lowsection>,<highsection>
          Restricts range of sections printed.  The section numbers must be
          decimal (not octal or hexadecimal).  Example: elfdump -s -d 8,10
          foo Use this to restrict the range of sections printed.  Various
          special sections print regardless of this.

     -Dc  Dumps conflict list in dynamic shared objects.

     -Dg  Dumps got table in dynamic shared objects.

     -dinfo
          Dumps .MIPS.dclass section.

     -dinst
          Dumps .MIPS.inst section.

     -Dl  Dumps library list in dynamic shared objects.

     -dsym
          Dumps .MIPS.sym section.

     -Dsymlib
          Dumps .MIPS.symlib.

     -Dt  Dumps the dynamic symbol table (the .dynsym section).

     -e   Dumps events sections.

     -f   Dumps the ELF header.

     -F   Dumps the literal tables.

     -g   Dumps an archive symbol table.

     -G   (O32 ABI only) Dumps gp table information.

     -h   Dumps all section headers in the file.

     -hash
          Dumps hash section entries.

     -i   Dumps the .interp section

     -ifc (n32 and 64 ABI only) Dump the .MIPS.interfaces section

     -info
          Dump information such as whether the object has been
          requickstarted (rqs(1)) or cord(1)ed.

     -l   This option emits a message suggesting you use the dwarfdump(1)
          or stdump(1) command to dump debugging line information.  For
          objects compiled with -64 or -n32, use dwarfdump.  For objects
          compiled with -32, use stdump.

     -L   Dumps the .dynamic (various flags and values) and the .liblist
          (list of named DSOs) sections.  (The .dynamic and .liblist
          sections are used by rld(1)).  The .liblist flag field prints D
          if the LL_DELAY_LOAD bit is on, E if the LL_EXPORTS bit is on, R
          if the LL_REQUIRE_MINOR bit is on, I if the LL_IGNORE_INT_VER bit
          is on, and M if the LL_EXACT_MATCH bit is on.  To see these
          sections with the values as uninterpreted numbers (for example,
          to see the actual flag bits in the .liblist), specify the
          -no_verbose option.

     -long
          When specified with the -L option, changes type names to print in
          full, matching names in elf.h.  Affects only the -L option.

     -n sectionname
          Dumps a named section.

     -no_verbose
          Turn off -v option.  For some fields that print string values,
          names or interpreted flag values, this changes the output to be
          the plain indexes or offsets or flag.

     -o   Dumps each program execution header.

     -op  Dumps the .options section.

     -p   Suppresses printing of headings.

     -Paddrs
          Dumps the .MIPS.Addrs section (a section created by pixie).

     -Pbinmap
          Dumps the .MIPS.Perf_bb_offsets section (a section created by
          pixie).

     -Pfuncnode
          Dumps the .MIPS.Perf_function section (a section created by
          pixie).

     -Pgraph
          Dumps the .MIPS.Perf_call_graph section (a section created by
          pixie).

     -Pperf
          Dumps the .MIPS.Perf_table section (a section created by
          pixie(1)).

     -Pweak
          Dumps the .MIPS.Perf_weak_names section (a section created by
          pixie).

     -r   Dumps relocation information.

     -R
     -reg Dumps register information (.reginfo section).

     -rpt (O32 ABI only) Dumps runtime procedure table.

     -s   Dumps contents of all sections (see -d description).

     -svr4
          Dump information in svr4 style.

     -t   Dumps symbol table (the .symtab section) entries.  (see also the
          -T <lowindex>,<highindex> option).  (Programs and DSOs do not
          normally have a .symtab section.  For programs and DSOs, use the
          -Dt option to print the .dynsym section.)

     -T <lowindex>,<highindex>
          Dumps the symbol table entries in the given range.  (Works like
          -t but restricted to a range of entries.)

     -v   Prints information in verbose form.  This is the default.
          Sometimes verbose means to interpret fields and print
          symbolically.  To turn this off (therefore printing the fields
          literally as numbers) use the -no_verbose option.

     -V   Dumps version information.

     -xl  Prints the translate section (Elf section type SHT_MIPS_XLATE) of
          an object file.  See xlate(4).  This is mostly intended for use
          by those working on tools that create this section, such as
          cord(1) or pixie(1).  O32-bit objects must be pixified.

     -xld Prints the translate debug section (Elf section type
          SHT_MIPS_XLATE_DEBUG) of an object file.  See xlate(4).  This is
          mostly intended for use by those working on tools that create
          this section, such as cord(1) or pixie(1).  O32-bit objects must
          be pixified.

     -xldi
          Dumps the translate debug section (SHT_MIPS_XLATE_DEBUG) of an
          object file in a form closely modeling the internal storage
          details.  This is mostly intended for use by those working on
          tools that create this section, such as cord(1) or pixie(1).
          O32-bit objects must be pixified.

     -xli Dumps the translate section (SHT_MIPS_XLATE) of an object file in
          a form closely modeling the internal storage details.  This is
          mostly intended for use by those working on tools that create
          this section, such as cord(1) or pixie(1).  O32-bit objects must
          be pixified.

     The elfdump command tries to format information in a helpful way,
     printing information in character, hexadecimal, octal, or decimal, as
     appropriate.

NOTES
     The -D and -l options, which formerly dumped debugging and line
     information, are no longer supported in elfdump.  To obtain debugging
     and line number information for 64-bit objects and objects compiled
     -n32, use the dwarfdump command.  For objects compiled -32 use the
     stdump command.

     The interaction of options with each other is mostly unspecified and
     the interactions can be surprising (with some option combinations a
     section might be printed more than once, for example).

SEE ALSO
     dwarfdump(1), stdump(1), ar(4), elf(4), a.out(4), xlate(4), odump(1),
     rqs(1)

     This man page is available only online.